This directory contains configuration files for the TaskManager 
used to run workflows on clusters as well as configuration files for the scheduler.

These files are tested by unit tests. 
Please use `hostname[_options]_manager.yml` for the manager files
and `hostname[_options]_scheduler_yml`.
